@@ -1,13 +1,17 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "Personel",
     "Finished" : "Achuet",
     "copy" : "eil",
+    "In Progress" : "War ar stern",
     "Done" : "Graet",
+    "The file was uploaded" : "Kaset eo bet ar restr",
+    "No file was uploaded" : "N'eus restr ebet a zo bet kaset",
     "Invalid date, date format must be YYYY-MM-DD" : "Deizat fall, stumm an deizat a zo ret bezhañ BBBB-MM-DD",
     "Cancel" : "Arrest",
     "Drop your files to upload" : "Laoskit ho restroù evit pellkas",
+    "Open" : "Digeriñ",
+    "Completed" : "Achuet",
     "Details" : "Munudoù",
     "Sharing" : "Rannan",
     "Tags" : "Klavioù",
@@ -25,21 +29,21 @@ OC.L10N.register(
     "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
     "Comments" : "Displegadennoù",
     "Modified" : "Cheñchet",
+    "Created" : "Krouet",
     "Save" : "Enrollañ",
     "Reply" : "Respont",
     "Update" : "Adnevesaat",
     "Created:" : "Krouet :",
     "Description" : "Diskrivadur",
-    "Completed" : "Achuet",
     "(group)" : "(strollad)",
     "seconds ago" : "eilenn zo",
+    "Search" : "Klask",
     "Shared with you" : "Rannet ganeoc'h",
-    "No notifications" : "Kemenaden ebet",
+    "No notifications" : "Kemennadenn ebet",
     "Today" : "Hiziv",
     "Tomorrow" : "Warc'hoaz",
     "Close" : "Seriñ",
     "Share" : "Rannan",
-    "Next week" : "Sizhun a zeu",
-    "Next month" : "Miz a zeu"
+    "Personal" : "Personel"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
