@@ -1,13 +1,13 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "Personol",
     "%s on %s" : "%s ar %s",
     "Done" : "Done",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Mae'r ffeil lwythwyd i fyny'n fwy na chyfarwyddeb MAX_FILE_SIZE bennwyd yn y ffurflen HTML",
     "No file was uploaded" : "Ni lwythwyd ffeil i fyny",
     "Missing a temporary folder" : "Plygell dros dro yn eisiau",
     "Cancel" : "Diddymu",
+    "Open" : "Ar Agor",
     "Details" : "Manylion",
     "Tags" : "Tagiau",
     "Activity" : "Gweithred",
@@ -25,13 +25,14 @@ OC.L10N.register(
     "Description" : "Disgrifiad",
     "Select Date" : "Dewis Dyddiad",
     "seconds ago" : "eiliad yn ôl",
+    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
+    "Search" : "Chwilio",
     "Shared with you" : "Shared with you",
     "No reminder" : "Dim nodyn atgoffa",
     "An error occurred" : "Digwyddodd gwall",
     "Today" : "Heddiw",
     "Close" : "Cau",
     "Share" : "Rhannu",
-    "Next week" : "Wythnos nesaf",
-    "Next month" : "Mis nesaf"
+    "Personal" : "Personol"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
