@@ -42,7 +42,6 @@ OC.L10N.register(
     "Deck" : "Kartaro",
     "Changes in the <strong>Deck app</strong>" : "Ŝanĝoj en la <strong>aplikaĵo Kartaro</strong>",
     "A <strong>comment</strong> was created on a card" : "<strong>Komento</strong> kreiĝis sur karton",
-    "Personal" : "Persona",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "La karto „%s“ sur „%s“ estis atribuita al vi de %s.",
     "The card \"%s\" on \"%s\" has reached its due date." : "La karto „%s“ sur „%s“ atingis sian limdaton.",
     "%s has mentioned you in a comment on \"%s\"." : "%s menciis vin en komento ĉe „%s“.",
@@ -54,12 +53,7 @@ OC.L10N.register(
     "Action needed" : "Ago bezonata",
     "Later" : "Poste",
     "copy" : "kopio",
-    "To do" : "Farota",
-    "Doing" : "Farata",
     "Done" : "Farita",
-    "Example Task 3" : "Ekzempla tasko 3",
-    "Example Task 2" : "Ekzempla tasko 2",
-    "Example Task 1" : "Ekzempla tasko 1",
     "The file was uploaded" : "La dosiero alŝutiĝis",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "La dosiero alŝutita superas la regulon „upload_max_filesize“ el „php.ini“",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "La dosiero alŝutita superas la regulon „MAX_FILE_SIZE“ specifita en la HTML-formularo",
@@ -76,6 +70,8 @@ OC.L10N.register(
     "File already exists" : "La dosiero jam ekzistas",
     "Add card" : "Aldoni karton",
     "Archived cards" : "Arĥivigitaj kartoj",
+    "Open" : "Malfermi",
+    "Completed" : "Plenumita",
     "Hide archived cards" : "Kaŝi arĥivigitajn kartojn",
     "Show archived cards" : "Montri arĥivigitajn kartojn",
     "Toggle compact mode" : "Baskuligi densigan vidon",
@@ -106,13 +102,14 @@ OC.L10N.register(
     "Description" : "Priskribo",
     "Formatting help" : "Helpo pri tekstaranĝo",
     "Remove due date" : "Viŝi limdaton",
-    "Completed" : "Plenumita",
     "Unarchive card" : "Malarĥivigi karton",
     "Archive card" : "Arĥivigi karton",
     "Select Date" : "Elekti daton",
     "(group)" : "(grupo)",
     "Delete card" : "Forigi karton",
     "seconds ago" : "antaŭ kelkaj sekundoj",
+    "Keyboard shortcuts" : "Fulmoklavoj",
+    "Search" : "Serĉi",
     "Archived boards" : "Arĥivigitaj tabuloj",
     "Shared with you" : "Kunhavata kun vi",
     "Edit board" : "Modifi tabulon",
@@ -121,6 +118,7 @@ OC.L10N.register(
     "No notifications" : "Neniu sciigo",
     "Delete board" : "Forigi tabulon",
     "An error occurred" : "Eraro okazis",
+    "Advanced options" : "Detalaj agordoj",
     "Today" : "Hodiaŭ",
     "Tomorrow" : "Morgaŭ",
     "Close" : "Malfermi",
@@ -128,9 +126,11 @@ OC.L10N.register(
     "Maximum file size of {size} exceeded" : "Maksimuma dosiergrando {size} transpasita",
     "Error creating the share" : "Eraro dum kreo de la kunhavigo",
     "Share" : "Kunhavigi",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Karta priskribo</strong> ene de la aplikaĵo Kartaro ŝanĝiĝis",
-    "Timeline" : "Kronologio",
-    "Due date" : "Limdato",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Limigo de Kartaro („Deck“) baros uzantojn, kiuj ne estas en tiuj grupoj, krei iliajn proprajn tabulojn. Uzantoj tamen eblos labori kun tabuloj kunhavigitaj kun ili."
+    "Personal" : "Persona",
+    "To do" : "Farota",
+    "Doing" : "Farata",
+    "Example Task 3" : "Ekzempla tasko 3",
+    "Example Task 2" : "Ekzempla tasko 2",
+    "Example Task 1" : "Ekzempla tasko 1"
 },
 "nplurals=2; plural=(n != 1);");
