@@ -1,7 +1,8 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "Isiklik",
+    "Deck" : "Deck",
+    "%s on %s" : "%s %s-l",
     "Finished" : "Lõpetatud",
     "Later" : "Hiljem",
     "copy" : "koopia",
@@ -49,9 +50,11 @@ OC.L10N.register(
     "Cancel edit" : "Loobu muutmisest",
     "No notifications" : "Märguandeid pole",
     "An error occurred" : "Tekkis tõrge",
+    "Advanced options" : "Täpsemad valikud",
     "Today" : "Täna",
     "Tomorrow" : "Homme",
     "Close" : "Sulge",
-    "Share" : "Jaga"
+    "Share" : "Jaga",
+    "Personal" : "Isiklik"
 },
 "nplurals=2; plural=(n != 1);");
