@@ -31,6 +31,7 @@ OC.L10N.register(
     "{user} has renamed the card {before} to {card}" : "{user} muutti kortin {before} uudeksi nimeksi {card}",
     "You have added a description to card {card} in list {stack} on board {board}" : "Olet lisännyt kuvauksen kortille {card} listalla {stack} taululla {board}",
     "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} on lisännyt kuvauksen kortille {card} listalla {stack} taululla {board}",
+    "You have updated the description of card {card} in list {stack} on board {board}" : "Olet päivittänyt kortin {card} kuvauksen listalla {stack} taululla {board}",
     "You have removed the due date of card {card}" : "Poistit eräpäivän kortilta {card}",
     "{user} has removed the due date of card {card}" : "{user} poisti eräpäivän kortilta {card}",
     "You have set the due date of card {card} to {after}" : "Asetit kortille {card} eräpäivän {after}",
@@ -56,24 +57,21 @@ OC.L10N.register(
     "A <strong>comment</strong> was created on a card" : "<strong>Kommentti</strong> luotiin kortille",
     "Upcoming cards" : "Tulevat kortit",
     "Load more" : "Lataa lisää",
-    "Personal" : "Henkilökohtainen",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortti \"%s\" taululla \"%s\" on asetettu sinulle käyttäjän %s toimesta.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Kortin \"%s\" on \"%s\" eräpäivä on tullut vastaan.",
     "%s has mentioned you in a comment on \"%s\"." : "%s mainitsi sinut kommentissa kortilla \"%s\".",
     "The board \"%s\" has been shared with you by %s." : "Taulu \"%s\" on jaettu kanssasi käyttäjän %s toimesta.",
+    "{user} has shared {deck-board} with you." : "{user} on jakanut taulun {deck-board} kanssasi.",
     "Deck board" : "Deck-taulu",
+    "Create a new deck card" : "Luo uusi kortti",
     "Card comments" : "Kortin kommentit",
     "Finished" : "Valmistunut",
     "To review" : "Arvosteltavana",
     "Action needed" : "Toimia vaaditaan",
     "Later" : "Myöhemmin",
     "copy" : "kopioi",
-    "To do" : "Odottaa",
-    "Doing" : "Tekeillä",
+    "To Do" : "Tehtävä",
     "Done" : "Valmis",
-    "Example Task 3" : "Esimerkkitehtävä 3",
-    "Example Task 2" : "Esimerkkitehtävä 2",
-    "Example Task 1" : "Esimerkkitehtävä 1",
     "The file was uploaded" : "Tiedosto lähetettiin",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lähetetty tiedosto ylittää php.ini-tiedostossa määritellyn upload_max_filesize -säännön ",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lähetettävän tiedoston enimmäiskoko ylittää HTML-lomakkeessa määritellyn MAX_FILE_SIZE-säännön",
@@ -86,11 +84,15 @@ OC.L10N.register(
     "Card not found" : "Korttia ei löydy",
     "Path is already shared with this card" : "Polku on jo jaettu tämän kortin kanssa",
     "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päivä, päivän muodon tulee olla YYYY-MM-DD",
+    "Card details" : "Näytä kortin sisältö",
     "Add board" : "Lisää taulu",
     "Select the board to link to a project" : "Valitse projektiin linkitettävä taulu",
     "Search by board title" : "Hae taulun otsikon mukaan",
     "Select board" : "Valitse taulu",
     "Select a board" : "Valitse taulu",
+    "No lists available" : "Ei listoja saatavilla",
+    "Select a list" : "Valitse lista ",
+    "Move card" : "Siirrä kortti",
     "Select a card" : "Valitse kortti",
     "Cancel" : "Peruuta",
     "Select the card to link to a project" : "Valitse projektiin linkitettävä kortti",
@@ -106,11 +108,16 @@ OC.L10N.register(
     "Archived cards" : "Arkistoidut kortit",
     "Add list" : "Lisää lista",
     "List name" : "Listan nimi",
+    "Active filters" : "Aktiiviset suodattimet",
     "Apply filter" : "Toteuta suodatus",
     "Filter by tag" : "Suodata tunnisteen perusteella",
-    "Filter by assigned user" : "Suodata määritetyn käyttäjän mukaan",
+    "Filter by assigned user" : "Suodata määritetyn käyttäjän perusteella",
     "Unassigned" : "Määrittämätön",
-    "Filter by due date" : "Suodata määräpäivän mukaan",
+    "Filter by status" : "Suodata tilan perusteella",
+    "Open and completed" : "Avoimet ja valmiit",
+    "Open" : "Avoimet",
+    "Completed" : "Valmiit",
+    "Filter by due date" : "Suodata määräpäivän perusteella",
     "Overdue" : "Myöhässä",
     "Next 24 hours" : "Seuraavat 24 tuntia",
     "Next 7 days" : "Seuraavat 7 päivää",
@@ -120,12 +127,13 @@ OC.L10N.register(
     "Hide archived cards" : "Piilota arkistoidut kortit",
     "Show archived cards" : "Näytä arkistoidut kortit",
     "Toggle compact mode" : "Käytä kompaktia tilaa",
+    "Hide card cover images" : "Piilota korttien kansikuvat",
+    "Show card cover images" : "Näytä korttien kansikuvat",
     "Open details" : "Avaa yksityiskohdat",
     "Details" : "Tiedot",
     "Loading board" : "Ladataan taulua",
-    "No lists available" : "Ei listoja saatavilla",
-    "Create a new list to add cards to this board" : "Lisää uusi lista lisätäksesi kortteja tälle taululle",
     "Board not found" : "Taulua ei löydy",
+    "Create a new list to add cards to this board" : "Lisää uusi lista lisätäksesi kortteja tälle taululle",
     "Sharing" : "Jakaminen",
     "Tags" : "Tunnisteet",
     "Deleted items" : "Poistetut tietueet",
@@ -133,16 +141,17 @@ OC.L10N.register(
     "Deleted lists" : "Poistetut listat",
     "Undo" : "Kumoa",
     "Deleted cards" : "Poistetut kortit",
-    "Share board with a user, group or circle …" : "Jaa taulu käyttäjän, ryhmän tai piirin ... kanssa",
+    "Share board with a user, group or team …" : "Jaa taulu käyttäjän, ryhmän tai tiimin kanssa...",
     "No participants found" : "Ei osallistujia löydetty",
     "Board owner" : "Taulun omistaja",
     "(Group)" : "(Ryhmä)",
-    "(Circle)" : "(Piiri)",
     "Can edit" : "Voi muokata",
     "Can share" : "Voi jakaa",
     "Can manage" : "Voi hallita",
     "Owner" : "Omistaja",
     "Delete" : "Poista",
+    "Failed to create share with {displayName}" : "Jaon luonti epäonnistui kohteen {displayName} kanssa",
+    "Are you sure you want to transfer the board {title} to {user}?" : "Haluatko varmasti siirtää taulun {title} käyttäjälle {user}?",
     "Transfer" : "Siirrä",
     "Archive all cards" : "Arkistoi kaikki kortit",
     "Delete list" : "Poista lista",
@@ -156,6 +165,8 @@ OC.L10N.register(
     "Board name" : "Taulun nimi",
     "Members" : "Jäsenet",
     "Upload new files" : "Lähetä uusia tiedostoja",
+    "Share from Files" : "Jaa tiedostoista",
+    "Pending share" : "Odottava jako",
     "Add this attachment" : "Lisää tämä liite",
     "Download" : "Lataa",
     "Remove attachment" : "Poista liite",
@@ -189,47 +200,60 @@ OC.L10N.register(
     "Write a description …" : "Kirjoita kuvaus…",
     "Choose attachment" : "Valitse liite",
     "Set a due date" : "Aseta eräpäivä",
+    "Choose a date" : "Valitse päivämäärä",
     "Remove due date" : "Poista eräpäivä",
-    "Completed" : "Valmistui",
-    "Not completed" : "Ei valmis",
+    "Mark as done" : "Merkitse valmiiksi",
     "Unarchive card" : "Poista kortti arkistosta",
     "Archive card" : "Arkistoi kortti",
     "Select Date" : "Valitse päivä",
     "Assign a tag to this card…" : "Lisää kortille tunniste...",
+    "Create a new tag:" : "Luo uusi tunniste:",
     "(group)" : "(ryhmä)",
     "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
     "{count} comments, {unread} unread" : "{count} kommenttia, {unread} lukematonta",
-    "Card details" : "Näytä kortin sisältö",
+    "Edit card title" : "Muokkaa kortin otsikkoa",
+    "Open link" : "Avaa linkki",
+    "Edit title" : "Muokkaa otsikkoa",
     "Assign to me" : "Määritä minulle",
     "Unassign myself" : "Poista määritys minulta",
-    "Mark as done" : "Merkitse valmiiksi",
-    "Move card" : "Siirrä kortti",
     "Delete card" : "Poista kortti",
-    "Move card to another board" : "Siirrä kortti toiselle taululle",
-    "Select a list" : "Valitse lista ",
-    "List is empty" : "Lista on tyhjä",
     "Card deleted" : "Kortti poistettu",
     "seconds ago" : "sekuntia sitten",
+    "Keyboard shortcuts" : "Pikanäppäimet",
+    "Keyboard shortcut" : "Näppäimistön pikanäppäin",
+    "Action" : "Toiminto",
+    "Shift" : "Siirrä",
+    "Search" : "Etsi",
+    "Mark card as completed/not completed" : "Merkitse kortti valmiiksi/avoimeksi",
     "All boards" : "Kaikki taulut",
     "Archived boards" : "Arkistoidut taulut",
     "Shared with you" : "Jaettu kanssasi",
+    "Deck settings" : "Pakan asetukset",
+    "Show boards in calendar/tasks" : "Näytä taulut kalenterissa ja tehtävissä",
+    "Cancel edit" : "Peruuta muokkaus",
     "Board details" : "Taulun tiedot",
     "Edit board" : "Muokkaa taulua",
     "Clone board" : "Monista taulu",
     "Unarchive board" : "Kumoa taulun arkistointi",
     "Archive board" : "Arkistoi taulu",
+    "Export board" : "Vie taulu",
     "All cards" : "Kaikki kortit",
     "No notifications" : "Ei ilmoituksia",
     "Delete board" : "Poista taulu",
     "Board {0} deleted" : "Taulu {0} poistettu",
     "No reminder" : "Ei muistutusta",
     "An error occurred" : "Tapahtui virhe",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Haluatko varmasti poistaa taulun {title}? Tämä poistaa kaikki taulun tiedot, mukaan lukien arkistoidut kortit.",
     "Delete the board?" : "Poistetaanko tämä taulu?",
+    "Clone cards" : "Kloonaa kortteja",
+    "Advanced options" : "Lisävalinnat",
+    "Clone" : "Kloonaa",
     "Today" : "Tänään",
     "Tomorrow" : "Huomenna",
     "Search for {searchQuery} in all boards" : "Hae ehtoja {searchQuery} kaikilta tauluilta",
     "No results found" : "Ei tuloksia",
-    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
+    "Click to expand description" : "Laajenna kuvausta ",
+    "{nbCards} cards" : "{nbCards} korttia    ",
     "Click to expand comment" : "Napsauta laajentaaksesi kommentin",
     "Create a new card" : "Luo uusi kortti",
     "Card title" : "Kortin otsikko",
@@ -240,6 +264,9 @@ OC.L10N.register(
     "Close" : "Sulje",
     "No upcoming cards" : "Ei tulevia kortteja",
     "upcoming cards" : "tulevat kortit",
+    "New card" : "Uusi kortti",
+    "Due on {date}" : "Määräpäivä {date}",
+    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
     "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
     "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
     "Link to a board" : "Linkki taululle",
@@ -250,12 +277,12 @@ OC.L10N.register(
     "Maximum file size of {size} exceeded" : "Tiedoston enimmäiskoko {size} ylitetty",
     "Error creating the share" : "Virhe jakoa luotaessa",
     "Share" : "Jaa",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Kortin kuvaus</strong> Pakka-sovelluksessa on vaihtunut",
-    "Timeline" : "Aikajana",
-    "Add a new list" : "Lisää uusi lista",
-    "Due date" : "Eräpäivä",
-    "Next week" : "Seuraava viikko",
-    "Next month" : "Seuraava kuukausi",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Pakan käytön rajoittaminen estää merkittyjen ryhmien jäseniä luomasta omia taulujaan, mutta käyttäjät pystyvät silti käyttämään heidän kanssaan jaettuja tauluja."
+    "Personal" : "Henkilökohtainen",
+    "To do" : "Odottaa",
+    "Doing" : "Tekeillä",
+    "Example Task 3" : "Esimerkkitehtävä 3",
+    "Example Task 2" : "Esimerkkitehtävä 2",
+    "Example Task 1" : "Esimerkkitehtävä 1",
+    "Move card to another board" : "Siirrä kortti toiselle taululle"
 },
 "nplurals=2; plural=(n != 1);");
