@@ -70,7 +70,6 @@ OC.L10N.register(
     "A <strong>card description</strong> has been changed" : "תיאור הכרטיס שונה",
     "Upcoming cards" : "כרטיסים עתידיים",
     "Load more" : "לטעון עוד",
-    "Personal" : "אישי",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "הכרטיס \"%s\" שב־„%s” הוקצה אליך על ידי %s.",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} has assigned the card {deck-card} on {deck-board} to you.",
     "The card \"%s\" on \"%s\" has reached its due date." : "הכרטיס „%s” שתחת „%s” הגיע למועד התפוגה שלו.",
@@ -83,12 +82,8 @@ OC.L10N.register(
     "Action needed" : "נדרשת פעולה",
     "Later" : "מאוחר יותר",
     "copy" : "עותק",
-    "To do" : "לעשות",
-    "Doing" : "בביצוע",
+    "To Do" : "מטלות",
     "Done" : "הסתיים",
-    "Example Task 3" : "משימה לדוגמה 3",
-    "Example Task 2" : "משימה לדוגמה 2",
-    "Example Task 1" : "משימה לדוגמה 1",
     "The file was uploaded" : "הקובץ הועלה",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "הקובץ שהועלה חורג מההנחיה upload_max_filesize ב־php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה חורג מההנחיה MAX_FILE_SIZE שצוינה בטופס ה־HTML",
@@ -107,13 +102,12 @@ OC.L10N.register(
     "Select the board to link to a project" : "נא לבחור את הלוח לקישור למיזם",
     "Search by board title" : "חיפוש לפי כותרת לו",
     "Select board" : "בחירת לוח",
-    "Move card to another board" : "העברת כרטיס ללוח אחר",
     "Select a board" : "נא לבחור לוח",
     "No lists available" : "אין רשימות זמינות",
     "Select a list" : "בחר רשימה",
     "Move card" : "העברת כרטיס",
-    "Cancel" : "ביטול",
     "Select a card" : "נא לבחור כרטיס",
+    "Cancel" : "ביטול",
     "Select the card to link to a project" : "נא לבחור את הכרטיס לקישור למיזם",
     "Link to card" : "קישור לכרטיס",
     "File already exists" : "הקובץ כבר קיים",
@@ -217,6 +211,7 @@ OC.L10N.register(
     "Select Date" : "בחירת תאריך",
     "Assign a tag to this card…" : "הקצאת תגית לכרטיס זה…",
     "(group)" : "(קבוצה)",
+    "Edit title" : "עריכת כותרת",
     "Assign to me" : "הקצאה אלי",
     "Unassign myself" : "לבטל את הקצאת עצמי",
     "Delete card" : "מחיקת כרטיס לארכיון",
@@ -250,6 +245,7 @@ OC.L10N.register(
     "No reminder" : "אין תזכורת",
     "An error occurred" : "אירעה שגיאה",
     "Delete the board?" : "למחוק את הלוח הזה?",
+    "Advanced options" : "אפשרויות מתקדמות",
     "Loading filtered view" : "טוען תצוגה מסוננת",
     "Today" : "היום",
     "Tomorrow" : "מחר",
@@ -268,8 +264,12 @@ OC.L10N.register(
     "Share with a Deck card" : "שיתוף עם כרטיס חפיסה",
     "Share {file} with a Deck card" : "שיתוף {file} עם כרטיס חפיסה",
     "Share" : "שיתוף",
-    "Searching for users, groups and circles …" : "מחפש משתמשים, קבוצות, ומעגלים ...",
-    "(Circle)" : "(מעגל)",
-    "Assign to users/groups/circles" : "הקצאה למשתמשים/קבוצות/מעגלים"
+    "Personal" : "אישי",
+    "To do" : "לעשות",
+    "Doing" : "בביצוע",
+    "Example Task 3" : "משימה לדוגמה 3",
+    "Example Task 2" : "משימה לדוגמה 2",
+    "Example Task 1" : "משימה לדוגמה 1",
+    "Move card to another board" : "העברת כרטיס ללוח אחר"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
