@@ -68,7 +68,6 @@ OC.L10N.register(
     "A <strong>comment</strong> was created on a card" : "Na kartici je stvoren <strong>komentar</strong>",
     "Upcoming cards" : "Nadolazeće kartice",
     "Load more" : "Učitaj više",
-    "Personal" : "Osobno",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Karticu „%s” na „%s” dodijelio vam je %s.",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vam je dodijelio karticu {deck-card} na {deck-board}.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Kartica „%s” na „%s” dosegla je datum dospijeća.",
@@ -86,12 +85,8 @@ OC.L10N.register(
     "Action needed" : "Potrebna radnja",
     "Later" : "Kasnije",
     "copy" : "kopiraj",
-    "To do" : "Zadatak",
-    "Doing" : "U postupku",
+    "To Do" : "Zadatak",
     "Done" : "Gotovo",
-    "Example Task 3" : "Primjer zadatka 3.",
-    "Example Task 2" : "Primjer zadatka 2.",
-    "Example Task 1" : "Primjer zadatka 1.",
     "The file was uploaded" : "Datoteka je otpremljena",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Otpremljena datoteka premašuje postavku upload_max_filesize u datoteci php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Otpremljena datoteka premašuje postavku MAX_FILE_SIZE koja je navedena u obrascu HTML-a",
@@ -110,13 +105,12 @@ OC.L10N.register(
     "Select the board to link to a project" : "Odaberite ploču za povezivanje s projektom",
     "Search by board title" : "Traži po naslovu ploče",
     "Select board" : "Odaberi ploču",
-    "Move card to another board" : "Premjesti karticu na drugu ploču",
     "Select a board" : "Odaberite ploču",
     "No lists available" : "Nema dostupnih popisa",
     "Select a list" : "Odaberi popis",
     "Move card" : "Premjesti karticu",
-    "Cancel" : "Odustani",
     "Select a card" : "Odaberite karticu",
+    "Cancel" : "Odustani",
     "Select the card to link to a project" : "Odaberite karticu za povezivanje s projektom",
     "Link to card" : "Poveznica na karticu",
     "File already exists" : "Datoteka već postoji",
@@ -224,6 +218,7 @@ OC.L10N.register(
     "Assign a tag to this card…" : "Dodijeli oznaku ovoj kartici...",
     "(group)" : "(grupa)",
     "{count} comments, {unread} unread" : "{count} komentara, {unread} nepročitanih",
+    "Edit title" : "Uredi naslov",
     "Assign to me" : "Dodijeli meni",
     "Unassign myself" : "Ukloni sebe",
     "Delete card" : "Izbriši karticu",
@@ -257,6 +252,9 @@ OC.L10N.register(
     "No reminder" : "Nema podsjetnika",
     "An error occurred" : "Došlo je do pogreške",
     "Delete the board?" : "Želite li izbrisati ploču?",
+    "Clone cards" : "Kloniraj kartice",
+    "Advanced options" : "Napredne opcije",
+    "Clone" : "Kloniraj",
     "Loading filtered view" : "Učitavanje filtriranog prikaza",
     "Today" : "Danas",
     "Tomorrow" : "Sutra",
@@ -284,8 +282,12 @@ OC.L10N.register(
     "Share with a Deck card" : "Dijeli s Deck karticom",
     "Share {file} with a Deck card" : "Dijeli {file} s Deck karticom",
     "Share" : "Dijeli",
-    "Searching for users, groups and circles …" : "Traženje korisnika, grupa i krugova...",
-    "(Circle)" : "(Krug)",
-    "Assign to users/groups/circles" : "Dodijeli korisnicima/grupama/krugovima"
+    "Personal" : "Osobno",
+    "To do" : "Zadatak",
+    "Doing" : "U postupku",
+    "Example Task 3" : "Primjer zadatka 3.",
+    "Example Task 2" : "Primjer zadatka 2.",
+    "Example Task 1" : "Primjer zadatka 1.",
+    "Move card to another board" : "Premjesti karticu na drugu ploču"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
