@@ -1,7 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "Անձնական",
     "Done" : "Done",
     "The file was uploaded" : "Նիշքը վերբերռնված է",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Վերբեռնած նիշքը գերազանցում է upload_max_filesize սահմանված php.ini֊ում",
@@ -12,6 +11,7 @@ OC.L10N.register(
     "Could not write file to disk" : "Չհաջողվեց գրառել նիշքը սկավառակի վրա",
     "A PHP extension stopped the file upload" : "PHP֊ի ընդլայնումն կանգնեցրեց նիշքի վերբեռնումը",
     "Cancel" : "ընդհատել",
+    "Completed" : "Ավարտվեց",
     "Details" : "Մանրամասներ",
     "Activity" : "Գործունեություն",
     "Can edit" : "Can edit",
@@ -26,11 +26,12 @@ OC.L10N.register(
     "Update" : "Թարմացնել",
     "Created:" : "Ստեղծված.",
     "Description" : "Նկարագրություն",
-    "Completed" : "Ավարտվեց",
     "seconds ago" : "վրկ. առաջ",
+    "Search" : "Search",
     "Shared with you" : "Shared with you",
     "Today" : "այսօր",
     "Close" : "Փակել",
-    "Share" : "Կիսվել"
+    "Share" : "Կիսվել",
+    "Personal" : "Անձնական"
 },
 "nplurals=2; plural=(n != 1);");
