@@ -67,7 +67,6 @@ OC.L10N.register(
     "Changes in the <strong>Deck app</strong>" : "Perubahan pada <strong>aplikasi Longgok</strong>",
     "A <strong>comment</strong> was created on a card" : "<strong>Komentar</strong> telah dibuat pada suatu kartu",
     "Upcoming cards" : "Kartu berikut",
-    "Personal" : "Personal",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kartu \"%s\" pada \"%s\" telah ditugaskan kepada Anda oleh %s.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Kartu \"%s\" pada \"%s\" telah melampaui tenggat.",
     "%s has mentioned you in a comment on \"%s\"." : "%s telah menyebut Anda didalam suatu komentar pada \"%s\".",
@@ -79,12 +78,8 @@ OC.L10N.register(
     "Action needed" : "Butuh tindakan",
     "Later" : "Nanti",
     "copy" : "salin",
-    "To do" : "Akan dikerjakan",
-    "Doing" : "Sedang dikerjakan",
+    "In Progress" : "Sedang Berlangsung",
     "Done" : "Selesai",
-    "Example Task 3" : "Contoh tugas 3",
-    "Example Task 2" : "Contoh tugas 2",
-    "Example Task 1" : "Contoh tugas 1",
     "The file was uploaded" : "Berkas terunggah",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Berkas terunggah melampau parameter upload_max_filesize pada php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Berkas yang diunggah melampaui direktif MAX_FILE_SIZE yang ditentukan dalam formulir HTML.",
@@ -102,12 +97,11 @@ OC.L10N.register(
     "Select the board to link to a project" : "Pilih papan untuk ditautkan ke proyek",
     "Search by board title" : "Cari berdasarkan judul papan",
     "Select board" : "Pilih papan",
-    "Move card to another board" : "Pindahkan kartu ke papan lain",
     "Select a board" : "Pilih papan",
     "Select a list" : "Pilih daftar",
     "Move card" : "Pindahkan kartu",
-    "Cancel" : "Membatalkan",
     "Select a card" : "Pilih kartu",
+    "Cancel" : "Membatalkan",
     "Select the card to link to a project" : "Pilih kartu untuk ditautkan ke proyek",
     "Link to card" : "Tautan ke kartu",
     "File already exists" : "Berkas sudah ada",
@@ -193,6 +187,7 @@ OC.L10N.register(
     "Archive card" : "Mengarsipkan kartu",
     "Assign a tag to this card…" : "Berikan tag pada kartu ini...",
     "(group)" : "(grup)",
+    "Edit title" : "Edit judul",
     "Assign to me" : "Tugaskan saya",
     "Delete card" : "Hapus kartu",
     "seconds ago" : "beberapa detik yang lalu",
@@ -213,6 +208,9 @@ OC.L10N.register(
     "Board {0} deleted" : "{0} papan terhapus",
     "An error occurred" : "Terjadi kesalahan",
     "Delete the board?" : "Hapus papan?",
+    "Clone cards" : "Klona kartu",
+    "Advanced options" : "Opsi lanjutan",
+    "Clone" : "Klona",
     "Today" : "Hari ini",
     "Tomorrow" : "Besok",
     "Click to expand comment" : "Klik untuk membuka komentar",
@@ -224,7 +222,12 @@ OC.L10N.register(
     "Something went wrong" : "Ada yang salah",
     "Maximum file size of {size} exceeded" : "Melampaui batas ukuran maksimal {size}",
     "Share" : "Bagikan",
-    "(Circle)" : "(Kelompok)",
-    "Assign to users/groups/circles" : "Penugasan kepada pengguna/grup/lingkaran"
+    "Personal" : "Personal",
+    "To do" : "Akan dikerjakan",
+    "Doing" : "Sedang dikerjakan",
+    "Example Task 3" : "Contoh tugas 3",
+    "Example Task 2" : "Contoh tugas 2",
+    "Example Task 1" : "Contoh tugas 1",
+    "Move card to another board" : "Pindahkan kartu ke papan lain"
 },
 "nplurals=1; plural=0;");
