@@ -2,7 +2,6 @@ OC.L10N.register(
     "deck",
     {
     "Deck" : "დასტა",
-    "Personal" : "პირადი",
     "The card \"%s\" on \"%s\" has reached its due date." : "ბარათმა \"%s\" \"%s\"-ზე მიაღწია დანიშნულ დროს.",
     "The board \"%s\" has been shared with you by %s." : "დაფა \"%s\" თქვენთან გაზიარდა %s-ისთვის.",
     "%s on %s" : "%s %s-ზე",
@@ -21,6 +20,7 @@ OC.L10N.register(
     "Do you want to overwrite it?" : "გსურთ მისი გადაწერა?",
     "Add card" : "ბარათის დამატება",
     "Filter by tag" : "ფილტრი ტეგებით",
+    "Completed" : "დასრულებული",
     "Hide archived cards" : "არქივირებული ბარათების დამალვა",
     "Show archived cards" : "არქივირებული ბარათების ჩვენება",
     "Details" : "დეტალები",
@@ -45,9 +45,12 @@ OC.L10N.register(
     "Description" : "აღწერა",
     "Formatting help" : "დახმარება ფორმატირებაზე",
     "Remove due date" : "მოაშორეთ დანიშნულების დრო",
-    "Completed" : "დასრულებული",
     "(group)" : "(ჯგუფი)",
     "seconds ago" : "წამის წინ",
+    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
+    "Keyboard shortcut" : "კლავიატურის კომბინაცია",
+    "Action" : "ქმედება",
+    "Search" : "ძიება",
     "Archived boards" : "არქივირებული დაფები",
     "Shared with you" : "გაზიარებული თქვენთან",
     "Board details" : "დაფის დეტალები",
@@ -56,10 +59,11 @@ OC.L10N.register(
     "Archive board" : "დაფის არქივირება",
     "No notifications" : "შეტყობინებები არაა",
     "Delete board" : "დაფის გაუქმება",
+    "Advanced options" : "დამატებითი ოპციონები",
     "Today" : "დღეს",
     "Tomorrow" : "ხვალ",
     "Close" : "დახურვა",
     "Share" : "გაზიარება",
-    "Due date" : "დროისთვის"
+    "Personal" : "პირადი"
 },
 "nplurals=2; plural=(n!=1);");
