@@ -1,12 +1,13 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "Perséinlech",
+    "In Progress" : "A Beaarbechtung",
     "Done" : "Done",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
     "No file was uploaded" : "Et ass kee Fichier ropgeluede ginn",
     "Missing a temporary folder" : "Et feelt en temporären Dossier",
     "Cancel" : "Ofbriechen",
+    "Completed" : "Erfëllt",
     "Details" : "Detailer",
     "Sharing" : "Gedeelt",
     "Tags" : "Tags",
@@ -24,12 +25,14 @@ OC.L10N.register(
     "Update" : "Update",
     "Created:" : "Erstallt:",
     "Description" : "Beschreiwung",
-    "Completed" : "Erfëllt",
     "seconds ago" : "Sekonnen hier",
+    "Search" : "Search",
     "Shared with you" : "Mat dir gedeelt",
+    "Advanced options" : "Erweidert Astellungen",
     "Today" : "Haut",
     "Tomorrow" : "Muer",
     "Close" : "Zoumaachen",
-    "Share" : "Deelen"
+    "Share" : "Deelen",
+    "Personal" : "Perséinlech"
 },
 "nplurals=2; plural=(n != 1);");
