@@ -1,12 +1,12 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "ສ່ວນບຸກຄົນ",
     "Finished" : "ສຳເລັດ",
     "Done" : "ສໍາເລັດ",
     "The file was uploaded" : "ຟາຍຖຶກອັບໂຫລດສຳເລັດ",
     "No file was uploaded" : "ບໍ່ມີການອັບໂຫລດຟາຍ",
     "Cancel" : "ຍົກເລີກ",
+    "Completed" : "ສຳເລັດ",
     "Details" : "ລາຍລະອຽດ",
     "Sharing" : "ການແບ່ງປັນ",
     "Tags" : "ປ້າຍກຳກັບ",
@@ -20,12 +20,13 @@ OC.L10N.register(
     "Comments" : "ຄໍາເຫັນ",
     "Modified" : "\"{name}\" ແມ່ນຊື່ໄຟລ໌ທີ່ບໍ່ຖືກຕ້ອງ.",
     "Save" : "ບັນທຶກ",
-    "Completed" : "ສຳເລັດ",
     "seconds ago" : "ວິນາທີຜ່ານມາ",
+    "Search" : "ຄົ້ນຫາ",
     "Shared with you" : "ແບ່ງປັບກັບທ່ານ",
     "No notifications" : "ບໍ່ມີການແຈ້ງເຕືອນ",
     "Today" : "ມື້ນີ້",
     "Close" : "ປິດ",
-    "Share" : "ແບ່ງປັນ"
+    "Share" : "ແບ່ງປັນ",
+    "Personal" : "ສ່ວນບຸກຄົນ"
 },
 "nplurals=1; plural=0;");
