@@ -66,7 +66,6 @@ OC.L10N.register(
     "A <strong>comment</strong> was created on a card" : "Kortelėje buvo sukurtas <strong>komentaras</strong>",
     "Upcoming cards" : "Artėjančios kortelės",
     "Load more" : "Įkelti daugiau",
-    "Personal" : "Asmeniniai",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortelę \"%s\" ties \"%s\" priskyrė jums %s.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Kortelė „%s“, esanti lentoje „%s“, pasiekė savo galutinį terminą.",
     "The card {deck-card} on {deck-board} has reached its due date." : "Kortelė {deck-card}, esanti lentoje {deck-board} pasiekė savo galutinio termino datą.",
@@ -79,12 +78,7 @@ OC.L10N.register(
     "Action needed" : "Reikalingas veiksmas",
     "Later" : "Vėliau",
     "copy" : "kopija",
-    "To do" : "Reikia atlikti",
-    "Doing" : "Atliekama",
     "Done" : "Atlikta",
-    "Example Task 3" : "Pavyzdinė užduotis 3",
-    "Example Task 2" : "Pavyzdinė užduotis 2",
-    "Example Task 1" : "Pavyzdinė užduotis 1",
     "The file was uploaded" : "Failas buvo įkeltas",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Įkeliamas failas viršija upload_max_filesize direktyvą, esančią faile php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Įkeltas failas viršija MAX_FILE_SIZE direktyvą, kuri buvo nurodyta HTML formoje",
@@ -103,13 +97,14 @@ OC.L10N.register(
     "Select the board to link to a project" : "Pasirinkite lentą, kurią susieti su projektu",
     "Search by board title" : "Ieškoti pagal lentos pavadinimą",
     "Select board" : "Pasirinkti lentą",
-    "Move card to another board" : "Perkelti kortelę į kitą lentą",
+    "Move/copy card" : "Perkelti/kopijuoti kortelę",
     "Select a board" : "Pasirinkite lentą",
     "No lists available" : "Nėra sąrašų",
     "Select a list" : "Pasirinkite sąrašą",
     "Move card" : "Perkelti kortelę",
-    "Cancel" : "Atsisakyti",
+    "Copy card" : "Kopijuoti kortelę",
     "Select a card" : "Pasirinkti kortelę",
+    "Cancel" : "Atsisakyti",
     "Select the card to link to a project" : "Pasirinkite kortelę, kurią susieti su projektu",
     "Link to card" : "Susieti su kortele",
     "File already exists" : "Failas jau yra",
@@ -139,6 +134,7 @@ OC.L10N.register(
     "Hide archived cards" : "Slėpti archyvuotas korteles",
     "Show archived cards" : "Rodyti archyvuotas korteles",
     "Toggle compact mode" : "Perjungti kompaktišką veikseną",
+    "Open details" : "Atverti išsamesnę informaciją",
     "Details" : "Išsamiau",
     "Loading board" : "Įkeliama lenta",
     "Board not found" : "Lenta nerasta",
@@ -153,6 +149,7 @@ OC.L10N.register(
     "No participants found" : "Nerasta jokių dalyvių",
     "Board owner" : "Lentos savininkas",
     "(Group)" : "(Grupė)",
+    "(Team)" : "(Komanda)",
     "Can edit" : "Gali redaguoti",
     "Can share" : "Can share",
     "Can manage" : "Gali tvarkyti",
@@ -216,6 +213,8 @@ OC.L10N.register(
     "(group)" : "(grupė)",
     "Next week – {timeLocale}" : "Kitą savaitę – {timeLocale}",
     "{count} comments, {unread} unread" : "Komentarų: {count}, neskaityta: {unread}",
+    "Open link" : "Atverti nuorodą",
+    "Edit title" : "Taisyti pavadinimą",
     "Assign to me" : "Priskirti sau",
     "Delete card" : "Ištrinti kortelę",
     "Card deleted" : "Kortelė ištrinta",
@@ -237,6 +236,7 @@ OC.L10N.register(
     "Clone board" : "Dubliuoti lentą",
     "Unarchive board" : "Išarchyvuoti lentą",
     "Archive board" : "Archyvuoti lentą",
+    "Export board" : "Eksportuoti lentą",
     "Turn on due date reminders" : "Įjungti priminimus apie galutinio termino datą",
     "Turn off due date reminders" : "Išjungti priminimus apie galutinio termino datą",
     "Due date reminders" : "Priminimai apie galutinio termino datą",
@@ -249,10 +249,16 @@ OC.L10N.register(
     "No reminder" : "Jokio priminimo",
     "An error occurred" : "Įvyko klaida",
     "Delete the board?" : "Ištrinti lentą?",
+    "Clone cards" : "Dubliuoti korteles",
+    "Advanced options" : "Išplėstinės parinktys",
+    "Restore archived cards" : "Atkurti archyvuotas korteles",
+    "Clone" : "Dubliuoti",
     "Today" : "Šiandien",
     "Tomorrow" : "Rytoj",
     "No due" : "Be galutinio termino",
     "No results found" : "Nerasta jokių rezultatų",
+    "Click to expand description" : "Spustelėkite norėdami išskleisti aprašą",
+    "Click to expand comment" : "Spustelėkite norėdami išskleisti komentarą",
     "Create a new card" : "Sukurti naują kortelę",
     "Card title" : "Kortelės pavadinimas",
     "Create card" : "Sukurti kortelę",
@@ -260,6 +266,7 @@ OC.L10N.register(
     "Card \"{card}\" was added to \"{board}\"" : "Kortelė „{card}“ buvo pridėta į lentą „{board}“",
     "Open card" : "Atverti kortelę",
     "Close" : "Užverti",
+    "New card" : "Nauja kortelė",
     "Due on {date}" : "Galutinis terminas {date}",
     "This weekend – {timeLocale}" : "Šį savaitgalį – {timeLocale}",
     "Tomorrow – {timeLocale}" : "Rytoj – {timeLocale}",
@@ -271,8 +278,12 @@ OC.L10N.register(
     "Maximum file size of {size} exceeded" : "Viršytas maksimalus {size} failo dydis",
     "Error creating the share" : "Klaida kuriant viešinį",
     "Share" : "Bendrinti",
-    "Searching for users, groups and circles …" : "Ieškoma naudotojų, grupių ir ratų…",
-    "(Circle)" : "(Ratas)",
-    "Assign to users/groups/circles" : "Priskirti naudotojams/grupėms/ratams"
+    "Personal" : "Asmeniniai",
+    "To do" : "Reikia atlikti",
+    "Doing" : "Atliekama",
+    "Example Task 3" : "Pavyzdinė užduotis 3",
+    "Example Task 2" : "Pavyzdinė užduotis 2",
+    "Example Task 1" : "Pavyzdinė užduotis 1",
+    "Move card to another board" : "Perkelti kortelę į kitą lentą"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
