@@ -68,7 +68,6 @@ OC.L10N.register(
     "A <strong>comment</strong> was created on a card" : "<strong>Коментар</strong> е креиран на картица",
     "Upcoming cards" : "Престојни картици",
     "Load more" : "Вчитај повеќе",
-    "Personal" : "Лично",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Картицата \"%s\" на \"%s\" ти е доделена од %s.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Картицата \"%s\" на \"%s\" го достигна датумот на истекување.",
     "%s has mentioned you in a comment on \"%s\"." : "%s те спомна во коментар на \"%s\".",
@@ -79,12 +78,8 @@ OC.L10N.register(
     "Action needed" : "Потребна е акција",
     "Later" : "Покасно",
     "copy" : "копирај",
-    "To do" : "За работење",
-    "Doing" : "Се работи",
+    "To Do" : "За правење",
     "Done" : "Готово",
-    "Example Task 3" : "Пример задача 3",
-    "Example Task 2" : "Пример задача 2",
-    "Example Task 1" : "Пример задача 1",
     "The file was uploaded" : "Датотеката е прикачена",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која беше специфицирана во HTML формата",
@@ -103,13 +98,12 @@ OC.L10N.register(
     "Select the board to link to a project" : "Избери табла за поврзување со проект",
     "Search by board title" : "Барај по име на табла",
     "Select board" : "Избери табла",
-    "Move card to another board" : "Премести ја картицата на друга табла",
     "Select a board" : "Избери табла",
     "No lists available" : "Нема достапни листи",
     "Select a list" : "Избери листа",
     "Move card" : "Премести картица",
-    "Cancel" : "Откажи",
     "Select a card" : "Избери картица",
+    "Cancel" : "Откажи",
     "Select the card to link to a project" : "Избери картица за поврзување со проект",
     "Link to card" : "Линк до картица",
     "File already exists" : "Датотека веќе постои",
@@ -214,6 +208,7 @@ OC.L10N.register(
     "Select Date" : "Избери датум",
     "Assign a tag to this card…" : "Додади ознака на оваа картица...",
     "(group)" : "(group)",
+    "Edit title" : "Удери наслов",
     "Assign to me" : "Доделени мене",
     "Unassign myself" : "Откажи се",
     "Delete card" : "Избриши картица",
@@ -248,6 +243,9 @@ OC.L10N.register(
     "No reminder" : "Нема потсетник",
     "An error occurred" : "Настана грешка",
     "Delete the board?" : "Бришење на таблата?",
+    "Clone cards" : "Клинирај картици",
+    "Advanced options" : "Напредни опции",
+    "Clone" : "Клонирај",
     "Loading filtered view" : "Вчитување на филтриран поглед",
     "Today" : "Денес",
     "Tomorrow" : "Утре",
@@ -274,8 +272,12 @@ OC.L10N.register(
     "Share with a Deck card" : "Споделено со Deck картица",
     "Share {file} with a Deck card" : "Сподели {file} со Deck картица",
     "Share" : "Сподели",
-    "Searching for users, groups and circles …" : "Пребарување на корисници, групи или кругови ...",
-    "(Circle)" : "(Круг)",
-    "Assign to users/groups/circles" : "Додели на корисници/групи/кругови"
+    "Personal" : "Лично",
+    "To do" : "За работење",
+    "Doing" : "Се работи",
+    "Example Task 3" : "Пример задача 3",
+    "Example Task 2" : "Пример задача 2",
+    "Example Task 1" : "Пример задача 1",
+    "Move card to another board" : "Премести ја картицата на друга табла"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
