@@ -1,7 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "Peribadi",
     "Done" : "Done",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Saiz fail yang dimuatnaik melebihi MAX_FILE_SIZE yang ditetapkan dalam borang HTML",
     "No file was uploaded" : "Tiada fail dimuatnaik",
@@ -23,6 +22,7 @@ OC.L10N.register(
     "Shared with you" : "Shared with you",
     "Today" : "Hari ini",
     "Close" : "Tutup",
-    "Share" : "Kongsi"
+    "Share" : "Kongsi",
+    "Personal" : "Peribadi"
 },
 "nplurals=1; plural=0;");
