@@ -1,7 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "Personal",
     "copy" : "copiar",
     "Done" : "Done",
     "The file was uploaded" : "Lo fichièr es estat enviat",
@@ -45,6 +44,7 @@ OC.L10N.register(
     "Update" : "Metre a jorn",
     "Created:" : "Creat lo :",
     "Description" : "Descripcion",
+    "Edit title" : "Modificar lo títol",
     "seconds ago" : "fa qualques segondas",
     "Keyboard shortcuts" : "Acorchis de clavièr",
     "Keyboard shortcut" : "Acorchis de clavièr",
@@ -53,6 +53,7 @@ OC.L10N.register(
     "Cancel edit" : "Anullar la modificacion",
     "No notifications" : "Cap de notificacion",
     "An error occurred" : "Una error s’es producha",
+    "Advanced options" : "Opcions avançadas",
     "Today" : "Uèi",
     "Tomorrow" : "Deman",
     "{stack} in {board}" : "{stack} dins {board}",
@@ -61,6 +62,7 @@ OC.L10N.register(
     "Close" : "Tampar",
     "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
     "Create a card" : "Crear una carta",
-    "Share" : "Partejar"
+    "Share" : "Partejar",
+    "Personal" : "Personal"
 },
 "nplurals=2; plural=(n > 1);");
