@@ -39,8 +39,8 @@ OC.L10N.register(
     "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} at annulladu s'archiviatzione de s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
     "You have removed the due date of card {card}" : "Ci nd'as bogadu sa data de iscadèntzia dae s'ischeda {card}",
     "{user} has removed the due date of card {card}" : "{user} ci nd'at bogadu sa data de iscadèntzia dae s'ischeda {card}",
-    "You have set the due date of card {card} to {after}" : "As impostadu sa data de iscadèntzia de s'ischeda {card} a su {after}",
-    "{user} has set the due date of card {card} to {after}" : "{user} at impostadu sa data de iscadèntzia de sa tèssera {card} a su {after}",
+    "You have set the due date of card {card} to {after}" : "As cunfiguradu sa data de iscadèntzia de s'ischeda {card} a su {after}",
+    "{user} has set the due date of card {card} to {after}" : "{user} at cunfiguradu sa data de iscadèntzia de sa tèssera {card} a su {after}",
     "You have updated the due date of card {card} to {after}" : "As agiornadu sa data de iscadèntzia de s'ischeda {card} a su {after}",
     "{user} has updated the due date of card {card} to {after}" : "{user} as agiornadu sa data de iscadèntzia de s'ischeda {card} a su {after}",
     "You have added the tag {label} to card {card} in list {stack} on board {board}" : "As agiuntu s'eticheta {label} a s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
@@ -68,7 +68,6 @@ OC.L10N.register(
     "A <strong>comment</strong> was created on a card" : "Unu <strong>cummentu</strong> est istadu creadu in s'ischeda",
     "Upcoming cards" : "Ischedas imbenientes",
     "Load more" : "Càrriga àteru",
-    "Personal" : "Personale",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "S'ischeda \"%s\" in \"%s\" s'est istadu assignadu dae %s.",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} t'at assignadu s'ischeda {deck-card} in {deck-board}.",
     "The card \"%s\" on \"%s\" has reached its due date." : "S'ischeda \"%s\" in \"%s\" est cròmpida a sa data de iscadèntzia.",
@@ -86,12 +85,8 @@ OC.L10N.register(
     "Action needed" : "Bisòngiat un'atzione",
     "Later" : "Luego",
     "copy" : "còpia",
-    "To do" : "De fàghere",
-    "Doing" : "In cursu",
+    "To Do" : "De fàghere",
     "Done" : "Fatu",
-    "Example Task 3" : "Atividade de esempru 3",
-    "Example Task 2" : "Atividade de esempru 2",
-    "Example Task 1" : "Atividade de esempru 1",
     "The file was uploaded" : "S'archìviu est istadu carrigadu",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "S'archìviu carrigadu superat sa diretiva upload_max_filesize in php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "S'archìviu carrigadu superat sa diretiva MAX_FILE_SIZE ispetzificada in su mòdulu HTML",
@@ -105,16 +100,20 @@ OC.L10N.register(
     "Path is already shared with this card" : "Su caminu est giai cumpartzidu cun cust'ischeda",
     "Invalid date, date format must be YYYY-MM-DD" : "Data non bàlida, su formadu de sa data depet èssere AAAA-MM-GG",
     "Personal planning and team project organization" : "Pranificatzione personale e organizatzione de su progetu de iscuadra",
+    "Card details" : "Detàllios ischeda",
     "Add board" : "Agiunghe lavagna",
     "Select the board to link to a project" : "Seletziona lavagna de collegare a unu progetu",
     "Search by board title" : "Chirca dae su tìtulu de sa lavagna",
     "Select board" : "Seletziona lavagna",
     "Select a board" : "Seletziona una lavagna",
+    "No lists available" : "Perunu elencu a disponimentu",
+    "Select a list" : "Seletziona un'elencu",
+    "Move card" : "Tràmuda ischeda",
     "Select a card" : "Seletziona un'ischeda",
     "Cancel" : "Annulla",
     "Select the card to link to a project" : "Seletzioan s'ischeda de collegare a unu progetu",
     "Link to card" : "Collega a un'ischeda",
-    "File already exists" : "Cust'archìviu ddoe est giai",
+    "File already exists" : "Custu archìviu ddoe est giai",
     "A file with the name {filename} already exists." : "B'at giai un'archìviu cun su nùmene de {filename}.",
     "Do you want to overwrite it?" : "Ddu cheres subraiscrìere? ",
     "Overwrite file" : "Subraiscrie archìviu",
@@ -129,6 +128,8 @@ OC.L10N.register(
     "Filter by tag" : "Filtra pro etichetas",
     "Filter by assigned user" : "Filtra pro utente assignadu",
     "Unassigned" : "No assignadu",
+    "Open" : "Aberi",
+    "Completed" : "Cumpletadu",
     "Filter by due date" : "Filtra pro data de iscadèntzia",
     "Overdue" : "Iscadèntzia",
     "Next 24 hours" : "24 oras imbenientes",
@@ -139,11 +140,11 @@ OC.L10N.register(
     "Hide archived cards" : "Cua is ischedas archiviadas",
     "Show archived cards" : "Mustra ischedas archiviadas",
     "Toggle compact mode" : "Càmbia a modalidade cumpata",
+    "Open details" : "Aberi is detàllios",
     "Details" : "Detàllios",
     "Loading board" : "Carrighende lavagna",
-    "No lists available" : "Perunu elencu a disponimentu",
-    "Create a new list to add cards to this board" : "Crea un'elencu nou de agiùnghere ischedas a custa lavagna",
     "Board not found" : "Lavagna no agatada",
+    "Create a new list to add cards to this board" : "Crea un'elencu nou de agiùnghere ischedas a custa lavagna",
     "Sharing" : "Cumpartzidura",
     "Tags" : "Etichetas",
     "Deleted items" : "Temas cantzellados",
@@ -151,12 +152,9 @@ OC.L10N.register(
     "Deleted lists" : "Elencos cantzellados",
     "Undo" : "Annulla",
     "Deleted cards" : "Ischeda cantzellada",
-    "Share board with a user, group or circle …" : "Cumpartzi lavagna cun un'utente, grupu o tropa...",
-    "Searching for users, groups and circles …" : "Chirchende utentes, grupos e tropas ...",
     "No participants found" : "Perunu partetzipante agatadu",
     "Board owner" : "Mere lavagna",
     "(Group)" : "(Grupu)",
-    "(Circle)" : "(Giru)",
     "Can edit" : "Faghet a modificare",
     "Can share" : "Faghet a cumpartzire",
     "Can manage" : "Faghet a gestire",
@@ -175,9 +173,8 @@ OC.L10N.register(
     "title and color value must be provided" : "tocat de frunire su tìtulu e su balore de su colore",
     "Board name" : "Nùmene de sa lavagna",
     "Members" : "Membros",
-    "Assign to users/groups/circles" : "Assigna a utentes/grupos/tropas",
     "Assign a user to this card…" : "Assigna utente a cust'ischeda...",
-    "Upload new files" : "Carriga archìvios noos",
+    "Upload new files" : "Càrriga archìvios noos",
     "Share from Files" : "Cumpartzi dae Archìvios",
     "Add this attachment" : "Agiunghe custu alligongiadu",
     "Show in Files" : "Mustra in Archìvios",
@@ -212,31 +209,33 @@ OC.L10N.register(
     "Add Attachment" : "Agiunghe alligongiadu",
     "Write a description …" : "Iscrie una descritzione ...",
     "Choose attachment" : "Sèbera un'alligongiadu",
-    "Set a due date" : "Imposta iscadèntzia",
+    "Set a due date" : "Cunfigura data de iscadèntzia",
     "Remove due date" : "Boga s'iscadèntzia",
-    "Completed" : "Cumpletadu",
+    "Mark as done" : "Marca comente cumpletadu",
     "Unarchive card" : "Ischeda no archiviada",
     "Archive card" : "Archìviu no archiviadu",
     "Select Date" : "Seletziona data",
     "Assign a tag to this card…" : "Assigna un'eticheta a cust'ischeda...",
+    "Create a new tag:" : "Crea un'eticheta noa:",
     "(group)" : "(grupu)",
     "{count} comments, {unread} unread" : "{count} cummentos, {unread} non lèghidos",
-    "Card details" : "Detàllios ischeda",
+    "Edit title" : "Modìfica tìtulu",
     "Assign to me" : "Assigna a mie",
     "Unassign myself" : "Annulla s'assignatzione a mie",
-    "Mark as done" : "Marca comente cumpletadu",
-    "Move card" : "Tràmuda ischeda",
     "Delete card" : "Cantzella ischeda",
-    "Move card to another board" : "Tràmuda s'ischeda a un'àtera lavagna",
-    "Select a list" : "Seletziona un'elencu",
-    "List is empty" : "Sa lista est bòida",
     "Card deleted" : "Ischeda cantzellada",
     "seconds ago" : "segundos a immoe",
+    "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
+    "Keyboard shortcut" : "Curtziadòrgiu de tecladu",
+    "Action" : "Atzione",
+    "Search" : "Chirca",
+    "Show help dialog" : "Mustra su diàlogu de agiudu",
     "All boards" : "Totu is lavagnas",
     "Archived boards" : "Lavagnas archiviadas",
     "Shared with you" : "Cumpartzidu cun tegus",
     "Use bigger card view" : "Imprea bista cun ischedas prus mannas",
     "Show boards in calendar/tasks" : "Mustra lavagnas in calendàriu/fainas",
+    "Cancel edit" : "Annulla modìfica",
     "Board details" : "Detàllios lavagna",
     "Edit board" : "Modìfica lavagna",
     "Clone board" : "Clona lavagna",
@@ -254,6 +253,9 @@ OC.L10N.register(
     "No reminder" : "Perunu apuntu",
     "An error occurred" : "B'at àpidu un'errore",
     "Delete the board?" : "Cheres cantzellare sa lavagna?",
+    "Clone cards" : "Clona ischeda",
+    "Advanced options" : "Sèberos avantzados",
+    "Clone" : "Clona",
     "Loading filtered view" : "Carrigamentu de sa bista cun su filtru",
     "Today" : "Oe",
     "Tomorrow" : "Cras",
@@ -270,6 +272,7 @@ OC.L10N.register(
     "Close" : "Serra",
     "No upcoming cards" : "Peruna ischeda abarrada",
     "upcoming cards" : "ischedas abarradas",
+    "New card" : "Carta noa",
     "Link to a board" : "Collega a una tabella",
     "Link to a card" : "Collega a un'ischeda",
     "Create a card" : "Crea un'ischeda",
@@ -281,14 +284,12 @@ OC.L10N.register(
     "Share with a Deck card" : "Cumpartzi cun un'ischeda deck",
     "Share {file} with a Deck card" : "Cumpartzi {file} cun un'ischeda de deck",
     "Share" : "Cumpartzi",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Sa <strong>descritzione de un'ischeda</strong> in intro de s'aplicatzione Deck app est istada cambiada",
-    "Timeline" : "Fusu oràriu",
-    "Add a new list" : "Agiunghe un'elencu nou",
-    "Assign to users" : "Assigna a utentes",
-    "Due date" : "Iscadèntzia",
-    "Next week" : "Sa chida chi benit",
-    "Next month" : "Su mese chi benit",
-    "Limit deck usage of groups" : "Mìnima s'impreu de deck de is grupos",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Su de minimare su deck at a impedire a is utentes chi non faghent parte de cuddos grupos de si creare lavagnas pròpias. Is utentes ant a èssere ancora capassos de traballare in is lavagnas chi fiant istadas cumpartzidas cun issos etotu,"
+    "Personal" : "Personale",
+    "To do" : "De fàghere",
+    "Doing" : "In cursu",
+    "Example Task 3" : "Atividade de esempru 3",
+    "Example Task 2" : "Atividade de esempru 2",
+    "Example Task 1" : "Atividade de esempru 1",
+    "Move card to another board" : "Tràmuda s'ischeda a un'àtera lavagna"
 },
 "nplurals=2; plural=(n != 1);");
