@@ -52,7 +52,6 @@ OC.L10N.register(
     "Changes in the <strong>Deck app</strong>" : "Зміни у застосунку <strong>Колода</strong>",
     "Upcoming cards" : "Очікують на виконання",
     "Load more" : "Більше",
-    "Personal" : "Особисте",
     "Deck board" : "Дошка Deck",
     "%s on %s" : "%s на %s",
     "Finished" : "Завершено",
@@ -60,12 +59,9 @@ OC.L10N.register(
     "Action needed" : "Потребує дій",
     "Later" : "Пізніше",
     "copy" : "копіювати",
-    "To do" : "Заплановано",
-    "Doing" : "Виконується",
+    "To Do" : "Зробити",
+    "In Progress" : "В процесі",
     "Done" : "Готово",
-    "Example Task 3" : "Приклад завдання 3",
-    "Example Task 2" : "Приклад завдання 2",
-    "Example Task 1" : "Приклад завдання 1",
     "The file was uploaded" : "Файл завантажено",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Файл для завантаження перевищує параметр upload_max_filesize у php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір завантаженого файлу перевищує значення MAX_FILE_SIZE, яке було зазначено у HTML формі",
@@ -82,12 +78,11 @@ OC.L10N.register(
     "Select the board to link to a project" : "Виберіть дошку для прив'зки до проєкту",
     "Search by board title" : "Шукати за назвою дошки",
     "Select board" : "Вибрати дошку",
-    "Move card to another board" : "Перемістити картку до іншої дошки",
     "Select a board" : "Вибрати дошку",
     "Select a list" : "Виберіть список",
     "Move card" : "Пересунути картку",
-    "Cancel" : "Скасувати",
     "Select a card" : "Вибрати картку",
+    "Cancel" : "Скасувати",
     "Select the card to link to a project" : "Виберіть картку для прив'язки до проєкту",
     "Link to card" : "Прив'язати до картки",
     "File already exists" : "Файл вже існує",
@@ -186,6 +181,8 @@ OC.L10N.register(
     "Next week – {timeLocale}" : "Наступного тижня - {timeLocale}",
     "Todo items" : "Пункти завдань",
     "Edit card title" : "Редагувати заголовок картки",
+    "Open link" : "Відкрити посилання",
+    "Edit title" : "Редагувати",
     "Assign to me" : "Призначити мені",
     "Delete card" : "Вилучити картку",
     "seconds ago" : "секунд тому",
@@ -218,6 +215,9 @@ OC.L10N.register(
     "An error occurred" : "Виникла помилка",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Ви впевнені, що хочете вилучити дошку {title}? Це призведе до видалення всіх даних цієї дошки, включно архівні картки.",
     "Delete the board?" : "Вилучити дошку?",
+    "Clone cards" : "Копіювати картки",
+    "Advanced options" : "Розширені налаштування",
+    "Clone" : "Копіювати",
     "Today" : "Сьогодні",
     "Tomorrow" : "Завтра",
     "No due" : "Без призначеної дати",
@@ -235,7 +235,12 @@ OC.L10N.register(
     "Maximum file size of {size} exceeded" : "Досягнуто максимальний розмір файлу {size}",
     "Error creating the share" : "Помилка створення спільного доступу",
     "Share" : "Спільний доступ",
-    "(Circle)" : "(Коло)",
-    "Assign to users/groups/circles" : "Призначити користувачам/групам/колам"
+    "Personal" : "Особисте",
+    "To do" : "Заплановано",
+    "Doing" : "Виконується",
+    "Example Task 3" : "Приклад завдання 3",
+    "Example Task 2" : "Приклад завдання 2",
+    "Example Task 1" : "Приклад завдання 1",
+    "Move card to another board" : "Перемістити картку до іншої дошки"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
