@@ -76,7 +76,7 @@ OC.L10N.register(
     "Cards due tomorrow" : "卡片於明日到期",
     "Upcoming cards" : "接下來的卡片",
     "Load more" : "載入更多",
-    "Personal" : "個人",
+    "Welcome to Nextcloud Deck!" : "歡迎使用 Nextcloud Deck！",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "卡片「%s」位於「%s」已由 %s 分配給您。",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} 已將位於 {deck-board} 的 {deck-card} 卡片分配給您。",
     "The card \"%s\" on \"%s\" has reached its due date." : "卡片「%s」位於「%s」已達到期日。",
@@ -99,12 +99,16 @@ OC.L10N.register(
     "Action needed" : "需要採取行動",
     "Later" : "稍後",
     "copy" : "複製",
-    "To do" : "待辦事項",
-    "Doing" : "正在進行",
+    "Read more inside" : "深入閱讀",
+    "Custom lists - click to rename!" : "自訂清單 - 點選以重新命名！",
+    "To Do" : "待辦",
+    "In Progress" : "進行中",
     "Done" : "完成",
-    "Example Task 3" : "範例工作 3",
-    "Example Task 2" : "範例工作 2",
-    "Example Task 1" : "範例工作 1",
+    "1. Open to learn more about boards and cards" : "1. 開啟以取得更多關於看板與卡片的資訊",
+    "2. Drag cards left and right, up and down" : "2. 將卡片向左、向右、向上或向下拖曳",
+    "3. Apply rich formatting and link content" : "3. 套用豐富格式與連結內容",
+    "4. Share, comment and collaborate!" : "4. 分享、留言與協作！",
+    "Create your first card!" : "建立您的第一張卡片！",
     "The file was uploaded" : "檔案已上傳",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
@@ -120,11 +124,17 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，日期格式必須為 YYYY-MM-DD",
     "Personal planning and team project organization" : "個人規劃與團隊專案組織",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck 是一套看板式組織工具，提供與 Nextcloud 整合的個人規劃與團隊專案組織功能。\n\n\n- 📥 將您的工作項目新增到卡片中，並將它們按順序排列\n- 📄 以 Markdown 編寫額外的註釋\n- 🔖 分配標籤讓組織更方便\n- 👥 與您的團隊、朋友與家人分享\n- 📎 附上檔案並將其嵌入到您的 Markdown 描述中\n- 💬 使用留言與您的團隊討論\n- ⚡ 追蹤活動流程中的變動\n- 🚀 整理好您的專案",
+    "Card details" : "卡片詳細資訊",
     "Add board" : "新增佈告欄",
     "Select the board to link to a project" : "選取要連結到專案的佈告欄",
     "Search by board title" : "按佈告欄標題搜尋",
     "Select board" : "選取佈告欄",
+    "Move/copy card" : "移動/複製卡片",
     "Select a board" : "選取佈告欄",
+    "No lists available" : "沒有可用的列表",
+    "Select a list" : "選取列表",
+    "Move card" : "移動卡片",
+    "Copy card" : "複製卡片",
     "Select a card" : "選取卡片",
     "Cancel" : "取消",
     "Select the card to link to a project" : "選取要連結到專案的卡片",
@@ -145,6 +155,10 @@ OC.L10N.register(
     "Filter by tag" : "按標籤過濾",
     "Filter by assigned user" : "按被分配的使用者過濾",
     "Unassigned" : "未分配",
+    "Filter by status" : "以狀態過濾",
+    "Open and completed" : "開啟並完成",
+    "Open" : "開啟",
+    "Completed" : "已完成",
     "Filter by due date" : "按到期日過濾",
     "Overdue" : "超過到期日",
     "Next 24 hours" : "接下來24小時",
@@ -163,9 +177,8 @@ OC.L10N.register(
     "Details" : "詳細資料",
     "Currently present people" : "目前在場夥伴",
     "Loading board" : "正在載入佈告欄",
-    "No lists available" : "沒有可用的列表",
-    "Create a new list to add cards to this board" : "建立新列表以新增卡片到此佈告欄",
     "Board not found" : "找不到佈告欄",
+    "Create a new list to add cards to this board" : "建立新列表以新增卡片到此佈告欄",
     "Sharing" : "分享",
     "Tags" : "標籤",
     "Deleted items" : "刪除的項目",
@@ -173,12 +186,12 @@ OC.L10N.register(
     "Deleted lists" : "已刪除的列表",
     "Undo" : "復原",
     "Deleted cards" : "已刪除的卡片",
-    "Share board with a user, group or circle …" : "與使用者、群組或小圈圈分享佈告欄……",
-    "Searching for users, groups and circles …" : "搜尋使用者、群組與小圈圈……",
+    "Share board with a user, group or team …" : "與使用者、群組或團隊分享佈告欄……",
+    "Searching for users, groups and teams …" : "搜尋使用者、群組與團隊……",
     "No participants found" : "找不到參與者",
     "Board owner" : "佈告欄擁有者",
     "(Group)" : "（群組）",
-    "(Circle)" : "（小圈圈）",
+    "(Team)" : "（團隊）",
     "Can edit" : "可以編輯",
     "Can share" : "可以分享",
     "Can manage" : "可以管理",
@@ -204,8 +217,9 @@ OC.L10N.register(
     "title and color value must be provided" : "必須提供標題與顏色的值",
     "Board name" : "佈告欄名稱",
     "Members" : "成員",
-    "Assign to users/groups/circles" : "分配給使用者／群組／小圈圈",
+    "Assign to users/groups/team" : "分配給使用者／群組／團隊",
     "Assign a user to this card…" : "分配使用者到此卡片……",
+    "Select a user to assign to this card…" : "選取要分配至此卡片的使用者……",
     "Upload new files" : "上傳新檔案",
     "Share from Files" : "從「檔案」分享",
     "Pending share" : "待分享",
@@ -248,9 +262,9 @@ OC.L10N.register(
     "Add due date" : "新增到期日",
     "Choose a date" : "選擇日期",
     "Remove due date" : "移除到期日",
-    "Completed" : "已完成",
+    "Mark as done" : "標記為完成",
     "Due at:" : "到期於：",
-    "Not completed" : "未完成",
+    "Not done" : "未完成",
     "Unarchive card" : "解除封存卡片",
     "Archive card" : "封存卡片",
     "Select Date" : "選擇日期",
@@ -259,24 +273,47 @@ OC.L10N.register(
     "Set due date for this weekend" : "設定本週末的到期日",
     "Set due date for next week" : "設定下週的到期日",
     "Assign a tag to this card…" : "分配標籤到此卡片……",
+    "Select or create a tag…" : "選取或建立標籤……",
     "Create a new tag:" : "建立新標籤：",
     "(group)" : "（群組）",
     "Next week – {timeLocale}" : "下週 – {timeLocale}",
     "Todo items" : "待辦事項",
     "{count} comments, {unread} unread" : "{count} 則留言，{unread} 則未讀",
     "Edit card title" : "編輯卡片標題",
-    "Card details" : "卡片詳細資訊",
+    "Open link" : "開啟連結",
+    "Edit title" : "編輯標題",
     "Assign to me" : "分配給我",
     "Unassign myself" : "取消分配給我",
     "Mark as not done" : "標記為未完成",
-    "Mark as done" : "標記為完成",
-    "Move card" : "移動卡片",
     "Delete card" : "刪除卡片",
-    "Move card to another board" : "將卡片移動到其他佈告欄",
-    "Select a list" : "選取列表",
-    "List is empty" : "清單為空",
     "Card deleted" : "卡片已刪除",
     "seconds ago" : "幾秒前",
+    "Keyboard shortcuts" : "鍵盤快速鍵",
+    "Boost your productivity using Deck with keyboard shortcuts." : "在 Deck 上利用鍵盤快捷鍵提高您的生產力。",
+    "Board actions" : "看板動作",
+    "Keyboard shortcut" : "鍵盤快捷鍵",
+    "Action" : "動作",
+    "Shift" : "Shift",
+    "Scroll" : "捲軸",
+    "Scroll sideways" : "橫向捲軸",
+    "Navigate between cards" : "在卡片間移動",
+    "Esc" : "Esc",
+    "Close card details" : "關閉卡片詳細資訊",
+    "Ctrl" : "Ctrl",
+    "Search" : "搜尋",
+    "Show card filters" : "顯示卡片篩選條件",
+    "Clear card filters" : "清除卡片篩選條件",
+    "Show help dialog" : "顯示說明對話方塊",
+    "Card actions" : "卡片動作",
+    "The following actions can be triggered on the currently highlighted card" : "可以在目前突顯的卡片上觸發以下動作",
+    "Enter" : "輸入",
+    "Space" : "空間",
+    "Open card details" : "開啟卡片詳細資訊",
+    "Edit the card title" : "編輯卡片標題",
+    "Assign yourself to the current card" : "將自己指派給目前的卡片",
+    "Archive/unarchive the current card" : "封存/解除封存目前卡片",
+    "Mark card as completed/not completed" : "將卡片標記為完成/未完成",
+    "Open card menu" : "開啟卡片選單",
     "All boards" : "所有佈告欄",
     "Archived boards" : "已封存的佈告欄",
     "Shared with you" : "與您分享",
@@ -286,6 +323,8 @@ OC.L10N.register(
     "Show boards in calendar/tasks" : "在日曆／工作項目中顯示佈告欄",
     "Limit board creation to some groups" : "限制僅某些群組可建立看板",
     "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "這些群組以外的使用者將無法建立自己的看板，但仍然可以在與他們分享的看板上工作。",
+    "Cancel edit" : "取消編輯",
+    "Save board" : "儲存佈告欄",
     "Board details" : "佈告欄詳細資訊",
     "Edit board" : "編輯佈告欄",
     "Clone board" : "再製佈告欄",
@@ -305,13 +344,21 @@ OC.L10N.register(
     "An error occurred" : "發生錯誤",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "您確定要刪除佈告欄 {title} 嗎？這將會刪除所有此佈告欄的資料，包含封存的卡片。",
     "Delete the board?" : "刪除佈告欄？",
+    "Clone {boardTitle}" : "再製 {boardTitle}",
+    "Clone cards" : "複製卡片",
+    "Clone assignments" : "再製工作",
+    "Clone labels" : "再製標籤",
+    "Clone due dates" : "再製截止日",
+    "Advanced options" : "進階選項",
+    "Move all cards to the first list" : "將所有卡片移動到第一個清單",
+    "Restore archived cards" : "還原已封存的卡片",
+    "Clone" : "複製",
     "Loading filtered view" : "正在載入過濾的檢視",
     "Today" : "今天",
     "Tomorrow" : "明天",
     "No due" : "無到期日",
     "Search for {searchQuery} in all boards" : "在所有佈告欄中搜尋 {searchQuery}",
     "No results found" : "找不到結果",
-    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
     "Deck board {name}\n* Last modified on {lastMod}" : "Deck 看板 {name}\n* 最後修改於 {lastMod}",
     "{stack} in {board}" : "{stack} 於 {board}",
     "Click to expand description" : "點擊展開描述",
@@ -331,6 +378,7 @@ OC.L10N.register(
     "upcoming cards" : "接下來的卡片",
     "New card" : "新卡片",
     "Due on {date}" : "於 {date} 到期",
+    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
     "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
     "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
     "Link to a board" : "連結到佈告欄",
@@ -344,14 +392,13 @@ OC.L10N.register(
     "Share with a Deck card" : "與 Deck 卡片分享",
     "Share {file} with a Deck card" : "與 Deck 卡片分享 {file}",
     "Share" : "分享",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Deck 應用程式中的<strong>卡片描述</strong>已變更",
-    "Timeline" : "時間軸",
-    "Add a new list" : "新增列表",
-    "Assign to users" : "分配給使用者",
-    "Due date" : "到期日",
-    "Next week" : "下週",
-    "Next month" : "下個月",
-    "Limit deck usage of groups" : "限制群組的 Deck 使用",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制 Deck 將會阻止不屬於這些群組的使用者建立自己的佈告欄。使用者仍然可以在與他們分享的佈告欄上工作。"
+    "Personal" : "個人",
+    "To do" : "待辦事項",
+    "Doing" : "正在進行",
+    "Example Task 3" : "範例工作 3",
+    "Example Task 2" : "範例工作 2",
+    "Example Task 1" : "範例工作 1",
+    "Move card to another board" : "將卡片移動到其他佈告欄",
+    "Filter by completed" : "按已完成篩選"
 },
 "nplurals=1; plural=0;");
