@@ -1,124 +1,71 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2016 Julius Härtl <jus@bitgrid.net>
- *
- * @copyright Copyright (c) 2019, Alexandru Puiu (alexpuiu20@yahoo.com)
- *
- * @author Julius Härtl <jus@bitgrid.net>
- * @author Maxence Lange <maxence@artificial-owl.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU Affero General Public License as
- *  published by the Free Software Foundation, either version 3 of the
- *  License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Affero General Public License for more details.
- *
- *  You should have received a copy of the GNU Affero General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Deck\Service;
 
 use OCA\Deck\Activity\ActivityManager;
 use OCA\Deck\Activity\ChangeSet;
+use OCA\Deck\BadRequestException;
+use OCA\Deck\Db\Acl;
 use OCA\Deck\Db\Assignment;
 use OCA\Deck\Db\AssignmentMapper;
+use OCA\Deck\Db\BoardMapper;
 use OCA\Deck\Db\Card;
 use OCA\Deck\Db\CardMapper;
-use OCA\Deck\Db\Acl;
 use OCA\Deck\Db\ChangeHelper;
 use OCA\Deck\Db\Label;
+use OCA\Deck\Db\LabelMapper;
 use OCA\Deck\Db\StackMapper;
 use OCA\Deck\Event\CardCreatedEvent;
 use OCA\Deck\Event\CardDeletedEvent;
 use OCA\Deck\Event\CardUpdatedEvent;
 use OCA\Deck\Model\CardDetails;
+use OCA\Deck\Model\OptionalNullableValue;
 use OCA\Deck\NoPermissionException;
 use OCA\Deck\Notification\NotificationHelper;
-use OCA\Deck\Db\BoardMapper;
-use OCA\Deck\Db\LabelMapper;
 use OCA\Deck\StatusException;
-use OCA\Deck\BadRequestException;
 use OCA\Deck\Validators\CardServiceValidator;
+use OCP\Collaboration\Reference\IReferenceManager;
 use OCP\Comments\ICommentsManager;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IRequest;
-use OCP\IUserManager;
 use OCP\IURLGenerator;
+use OCP\IUserManager;
 use Psr\Log\LoggerInterface;
 
 class CardService {
-	private CardMapper $cardMapper;
-	private StackMapper $stackMapper;
-	private BoardMapper $boardMapper;
-	private LabelMapper $labelMapper;
-	private PermissionService $permissionService;
-	private BoardService $boardService;
-	private NotificationHelper $notificationHelper;
-	private AssignmentMapper $assignedUsersMapper;
-	private AttachmentService $attachmentService;
-	private ?string $currentUser;
-	private ActivityManager $activityManager;
-	private ICommentsManager $commentsManager;
-	private ChangeHelper $changeHelper;
-	private IEventDispatcher $eventDispatcher;
-	private IUserManager $userManager;
-	private IURLGenerator $urlGenerator;
-	private LoggerInterface $logger;
-	private IRequest $request;
-	private CardServiceValidator $cardServiceValidator;
-
 	public function __construct(
-		CardMapper $cardMapper,
-		StackMapper $stackMapper,
-		BoardMapper $boardMapper,
-		LabelMapper $labelMapper,
-		PermissionService $permissionService,
-		BoardService $boardService,
-		NotificationHelper $notificationHelper,
-		AssignmentMapper $assignedUsersMapper,
-		AttachmentService $attachmentService,
-		ActivityManager $activityManager,
-		ICommentsManager $commentsManager,
-		IUserManager $userManager,
-		ChangeHelper $changeHelper,
-		IEventDispatcher $eventDispatcher,
-		IURLGenerator $urlGenerator,
-		LoggerInterface $logger,
-		IRequest $request,
-		CardServiceValidator $cardServiceValidator,
-		?string $userId
+		private CardMapper $cardMapper,
+		private StackMapper $stackMapper,
+		private BoardMapper $boardMapper,
+		private LabelMapper $labelMapper,
+		private LabelService $labelService,
+		private PermissionService $permissionService,
+		private BoardService $boardService,
+		private NotificationHelper $notificationHelper,
+		private AssignmentMapper $assignedUsersMapper,
+		private AttachmentService $attachmentService,
+		private ActivityManager $activityManager,
+		private ICommentsManager $commentsManager,
+		private IUserManager $userManager,
+		private ChangeHelper $changeHelper,
+		private IEventDispatcher $eventDispatcher,
+		private IURLGenerator $urlGenerator,
+		private LoggerInterface $logger,
+		private IRequest $request,
+		private CardServiceValidator $cardServiceValidator,
+		private AssignmentService $assignmentService,
+		private IReferenceManager $referenceManager,
+		private ?string $userId,
 	) {
-		$this->cardMapper = $cardMapper;
-		$this->stackMapper = $stackMapper;
-		$this->boardMapper = $boardMapper;
-		$this->labelMapper = $labelMapper;
-		$this->permissionService = $permissionService;
-		$this->boardService = $boardService;
-		$this->notificationHelper = $notificationHelper;
-		$this->assignedUsersMapper = $assignedUsersMapper;
-		$this->attachmentService = $attachmentService;
-		$this->activityManager = $activityManager;
-		$this->commentsManager = $commentsManager;
-		$this->userManager = $userManager;
-		$this->changeHelper = $changeHelper;
-		$this->eventDispatcher = $eventDispatcher;
-		$this->currentUser = $userId;
-		$this->urlGenerator = $urlGenerator;
-		$this->logger = $logger;
-		$this->request = $request;
-		$this->cardServiceValidator = $cardServiceValidator;
 	}
 
 	public function enrichCards($cards) {
-		$user = $this->userManager->get($this->currentUser);
+		$user = $this->userManager->get($this->userId);
 
 		$cardIds = array_map(function (Card $card) use ($user) {
 			// Everything done in here might be heavy as it is executed for every card
@@ -158,11 +105,21 @@ class CardService {
 
 		return array_map(
 			function (Card $card): CardDetails {
-				return new CardDetails($card);
+				$cardDetails = new CardDetails($card);
+
+				$references = $this->referenceManager->extractReferences($card->getTitle());
+				$reference = array_shift($references);
+				if ($reference) {
+					$referenceData = $this->referenceManager->resolveReference($reference);
+					$cardDetails->setReferenceData($referenceData);
+				}
+
+				return $cardDetails;
 			},
 			$cards
 		);
 	}
+
 	public function fetchDeleted($boardId) {
 		$this->cardServiceValidator->check(compact('boardId'));
 		$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_READ);
@@ -242,6 +199,8 @@ class CardService {
 		$this->changeHelper->cardChanged($card->getId(), false);
 		$this->eventDispatcher->dispatchTyped(new CardCreatedEvent($card));
 
+		[$card] = $this->enrichCards([$card]);
+
 		return $card;
 	}
 
@@ -284,6 +243,9 @@ class CardService {
 	 * @param $description
 	 * @param $order
 	 * @param $duedate
+	 * @param $deletedAt
+	 * @param $archived
+	 * @param $done
 	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws StatusException
 	 * @throws \OCA\Deck\NoPermissionException
@@ -291,10 +253,10 @@ class CardService {
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function update($id, $title, $stackId, $type, $owner, $description = '', $order = 0, $duedate = null, $deletedAt = null, $archived = null) {
+	public function update($id, $title, $stackId, $type, $owner, $description = '', $order = 0, $duedate = null, $deletedAt = null, $archived = null, ?OptionalNullableValue $done = null) {
 		$this->cardServiceValidator->check(compact('id', 'title', 'stackId', 'type', 'owner', 'order'));
 
-		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
+		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT, allowDeletedCard: true);
 		$this->permissionService->checkPermission($this->stackMapper, $stackId, Acl::PERMISSION_EDIT);
 
 		if ($this->boardService->isArchived($this->cardMapper, $id)) {
@@ -304,8 +266,16 @@ class CardService {
 		if ($archived !== null && $card->getArchived() && $archived === true) {
 			throw new StatusException('Operation not allowed. This card is archived.');
 		}
+
+		if ($card->getDeletedAt() !== 0) {
+			if ($deletedAt === null || $deletedAt > 0) {
+				// Only allow operations when restoring the card
+				throw new NoPermissionException('Operation not allowed. This card was deleted.');
+			}
+		}
+
 		$changes = new ChangeSet($card);
-		if ($card->getLastEditor() !== $this->currentUser && $card->getLastEditor() !== null) {
+		if ($card->getLastEditor() !== $this->userId && $card->getLastEditor() !== null) {
 			$this->activityManager->triggerEvent(
 				ActivityManager::DECK_OBJECT_CARD,
 				$card,
@@ -318,7 +288,7 @@ class CardService {
 			);
 
 			$card->setDescriptionPrev($card->getDescription());
-			$card->setLastEditor($this->currentUser);
+			$card->setLastEditor($this->userId);
 		}
 		$card->setTitle($title);
 		$card->setStackId($stackId);
@@ -341,6 +311,11 @@ class CardService {
 		if ($archived !== null) {
 			$card->setArchived($archived);
 		}
+		if ($done !== null) {
+			$card->setDone($done->getValue());
+		} else {
+			$card->setDone(null);
+		}
 
 
 		// Trigger update events before setting description as it is handled separately
@@ -352,8 +327,34 @@ class CardService {
 		}
 		$card->setDescription($description);
 
-
+		// @var Card $card
 		$card = $this->cardMapper->update($card);
+		$oldBoardId = $this->stackMapper->findBoardId($changes->getBefore()->getStackId());
+		$boardId = $this->cardMapper->findBoardId($card->getId());
+		if ($boardId !== $oldBoardId) {
+			$stack = $this->stackMapper->find($card->getStackId());
+			$board = $this->boardService->find($this->cardMapper->findBoardId($card->getId()));
+			$boardLabels = $board->getLabels() ?? [];
+			foreach ($card->getLabels() as $cardLabel) {
+				$this->removeLabel($card->getId(), $cardLabel->getId());
+				$label = $this->labelMapper->find($cardLabel->getId());
+				$filteredLabels = array_values(array_filter($boardLabels, fn ($item) => $item->getTitle() === $label->getTitle()));
+				// clone labels that are assigned to card but don't exist in new board
+				if (empty($filteredLabels)) {
+					if ($this->permissionService->getPermissions($boardId)[Acl::PERMISSION_MANAGE] === true) {
+						$newLabel = $this->labelService->create($label->getTitle(), $label->getColor(), $board->getId());
+						$boardLabels[] = $label;
+						$this->assignLabel($card->getId(), $newLabel->getId());
+					}
+				} else {
+					$this->assignLabel($card->getId(), $filteredLabels[0]->getId());
+				}
+			}
+			$board->setLabels($boardLabels);
+			$this->boardMapper->update($board);
+			$this->changeHelper->boardChanged($board->getId());
+		}
+
 		if ($resetDuedateNotification) {
 			$this->notificationHelper->markDuedateAsRead($card);
 		}
@@ -361,9 +362,43 @@ class CardService {
 
 		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card, $changes->getBefore()));
 
+		[$card] = $this->enrichCards([$card]);
+
 		return $card;
 	}
 
+	public function cloneCard(int $id, ?int $targetStackId = null):Card {
+		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_READ);
+		$originCard = $this->cardMapper->find($id);
+		if ($targetStackId === null) {
+			$targetStackId = $originCard->getStackId();
+		}
+		$this->permissionService->checkPermission($this->stackMapper, $targetStackId, Acl::PERMISSION_EDIT);
+		$newCard = $this->create($originCard->getTitle(), $targetStackId, $originCard->getType(), $originCard->getOrder(), $originCard->getOwner());
+		$boardId = $this->stackMapper->findBoardId($targetStackId);
+		foreach ($this->labelMapper->findAssignedLabelsForCard($id) as $label) {
+			if ($boardId != $this->stackMapper->findBoardId($originCard->getStackId())) {
+				try {
+					$label = $this->labelService->cloneLabelIfNotExists($label->getId(), $boardId);
+				} catch (NoPermissionException $e) {
+					break;
+				}
+			}
+			$this->assignLabel($newCard->getId(), $label->getId());
+		}
+		foreach ($this->assignedUsersMapper->findAll($id) as $assignement) {
+			try {
+				$this->permissionService->checkPermission($this->cardMapper, $newCard->getId(), Acl::PERMISSION_READ, $assignement->getParticipant());
+			} catch (NoPermissionException $e) {
+				continue;
+			}
+			$this->assignmentService->assignUser($newCard->getId(), $assignement->getParticipant());
+		}
+		$newCard->setDescription($originCard->getDescription());
+		$card = $this->enrichCards([$this->cardMapper->update($newCard)]);
+		return $card[0];
+	}
+
 	/**
 	 * @param $id
 	 * @param $title
@@ -511,6 +546,57 @@ class CardService {
 		return $newCard;
 	}
 
+	/**
+	 * @param $id
+	 * @return \OCA\Deck\Db\Card
+	 * @throws StatusException
+	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws \OCP\AppFramework\Db\DoesNotExistException
+	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
+	 * @throws BadRequestException
+	 */
+	public function done(int $id): Card {
+		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
+		if ($this->boardService->isArchived($this->cardMapper, $id)) {
+			throw new StatusException('Operation not allowed. This board is archived.');
+		}
+		$card = $this->cardMapper->find($id);
+		$card->setDone(new \DateTime());
+		$newCard = $this->cardMapper->update($card);
+		$this->notificationHelper->markDuedateAsRead($card);
+		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_CARD, $newCard, ActivityManager::SUBJECT_CARD_UPDATE_DONE);
+		$this->changeHelper->cardChanged($id, false);
+
+		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
+
+		return $newCard;
+	}
+
+	/**
+	 * @param $id
+	 * @return \OCA\Deck\Db\Card
+	 * @throws StatusException
+	 * @throws \OCA\Deck\NoPermissionException
+	 * @throws \OCP\AppFramework\Db\DoesNotExistException
+	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
+	 * @throws BadRequestException
+	 */
+	public function undone(int $id): Card {
+		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
+		if ($this->boardService->isArchived($this->cardMapper, $id)) {
+			throw new StatusException('Operation not allowed. This board is archived.');
+		}
+		$card = $this->cardMapper->find($id);
+		$card->setDone(null);
+		$newCard = $this->cardMapper->update($card);
+		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_CARD, $newCard, ActivityManager::SUBJECT_CARD_UPDATE_UNDONE);
+		$this->changeHelper->cardChanged($id, false);
+
+		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
+
+		return $newCard;
+	}
+
 	/**
 	 * @param $cardId
 	 * @param $labelId
@@ -569,13 +655,13 @@ class CardService {
 		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
 	}
 
-	public function getCardUrl($cardId) {
+	public function getCardUrl(int $cardId): string {
 		$boardId = $this->cardMapper->findBoardId($cardId);
 
-		return $this->urlGenerator->linkToRouteAbsolute('deck.page.index') . "#/board/$boardId/card/$cardId";
+		return $this->urlGenerator->linkToRouteAbsolute('deck.page.indexCard', ['boardId' => $boardId, 'cardId' => $cardId]);
 	}
 
-	public function getRedirectUrlForCard($cardId) {
-		return $this->urlGenerator->linkToRouteAbsolute('deck.page.index') . "card/$cardId";
+	public function getRedirectUrlForCard(int $cardId): string {
+		return $this->urlGenerator->linkToRouteAbsolute('deck.page.redirectToCard', ['cardId' => $cardId]);
 	}
 }
